@@ -53,8 +53,9 @@ class Kinesis(Sink):
             ),
         )
 
-    def _sink(self, messages: List[dict]) -> None:
+    def _sink(self, messages: List[dict]) -> bool:
         """Send records to Kinesis Stream"""
+        no_error = True
         for chunk in self._chunks(messages, self._batch_size):
             records = [
                 {
@@ -70,7 +71,10 @@ class Kinesis(Sink):
                 )
             except ClientError as error:
                 logger.error(f"Error putting Kinesis records, error: {error}")
-                raise
+                no_error = False
             else:
                 # TODO: error handling of some records failure within batch
                 logger.info(f"Sent {len(chunk)} records. Response {response}")
+                no_error = False
+
+        return no_error
