@@ -21,11 +21,6 @@ T = TypeVar("T")
 EnumT = TypeVar("EnumT", bound=Enum)
 
 
-def from_str(x: Any) -> str:
-    assert isinstance(x, str)
-    return x
-
-
 def from_none(x: Any) -> Any:
     assert x is None
     return x
@@ -40,6 +35,16 @@ def from_union(fs, x):
     assert False
 
 
+def from_str(x: Any) -> str:
+    assert isinstance(x, str)
+    return x
+
+
+def to_enum(c: Type[EnumT], x: Any) -> EnumT:
+    assert isinstance(x, c)
+    return x.value
+
+
 def from_float(x: Any) -> float:
     assert isinstance(x, (float, int)) and not isinstance(x, bool)
     return float(x)
@@ -69,11 +74,6 @@ def to_class(c: Type[T], x: Any) -> dict:
     return cast(Any, x).to_dict()
 
 
-def to_enum(c: Type[EnumT], x: Any) -> EnumT:
-    assert isinstance(x, c)
-    return x.value
-
-
 class AspectType(Enum):
     DASHBOARD_INFO = "DASHBOARD_INFO"
     DASHBOARD_UPSTREAM = "DASHBOARD_UPSTREAM"
@@ -91,18 +91,40 @@ class AspectType(Enum):
     PROPERTIES = "PROPERTIES"
 
 
+class ChartType(Enum):
+    AREA = "AREA"
+    BAR = "BAR"
+    BOX_PLOT = "BOX_PLOT"
+    COLUMN = "COLUMN"
+    DONUT = "DONUT"
+    FUNNEL = "FUNNEL"
+    LINE = "LINE"
+    MAP = "MAP"
+    OTHER = "OTHER"
+    PIE = "PIE"
+    SCATTER = "SCATTER"
+    TABLE = "TABLE"
+    TEXT = "TEXT"
+    TIMELINE = "TIMELINE"
+    UNKNOWN = "UNKNOWN"
+    WATERFALL = "WATERFALL"
+
+
 @dataclass
 class Chart:
+    chart_type: Optional[ChartType] = None
     title: Optional[str] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'Chart':
         assert isinstance(obj, dict)
+        chart_type = from_union([ChartType, from_none], obj.get("chartType"))
         title = from_union([from_str, from_none], obj.get("title"))
-        return Chart(title)
+        return Chart(chart_type, title)
 
     def to_dict(self) -> dict:
         result: dict = {}
+        result["chartType"] = from_union([lambda x: to_enum(ChartType, x), from_none], self.chart_type)
         result["title"] = from_union([from_str, from_none], self.title)
         return result
 
@@ -1237,7 +1259,6 @@ class PersonProperties:
     primary_phone: Optional[str] = None
     provider_name: Optional[str] = None
     status: Optional[str] = None
-    title: Optional[str] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'PersonProperties':
@@ -1260,8 +1281,7 @@ class PersonProperties:
         primary_phone = from_union([from_str, from_none], obj.get("primaryPhone"))
         provider_name = from_union([from_str, from_none], obj.get("providerName"))
         status = from_union([from_str, from_none], obj.get("status"))
-        title = from_union([from_str, from_none], obj.get("title"))
-        return PersonProperties(id, aspect_type, avatar_url, created_at, display_name, entity_id, first_name, full_name, person_properties_id, issuer, last_login, last_name, latest, mobile_phone, occupation, primary_phone, provider_name, status, title)
+        return PersonProperties(id, aspect_type, avatar_url, created_at, display_name, entity_id, first_name, full_name, person_properties_id, issuer, last_login, last_name, latest, mobile_phone, occupation, primary_phone, provider_name, status)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -1283,7 +1303,6 @@ class PersonProperties:
         result["primaryPhone"] = from_union([from_str, from_none], self.primary_phone)
         result["providerName"] = from_union([from_str, from_none], self.provider_name)
         result["status"] = from_union([from_str, from_none], self.status)
-        result["title"] = from_union([from_str, from_none], self.title)
         return result
 
 
