@@ -18,6 +18,7 @@ from metaphor.common.metadata_change_event import (
     MetadataChangeEvent,
     Person,
     PersonID,
+    PersonProperties,
 )
 
 logger = logging.getLogger()
@@ -109,10 +110,13 @@ class GoogleDirectoryExtractor(BaseExtractor):
         person.entity_type = EntityType.PERSON
         person.logical_id = PersonID()
         person.logical_id.email = user["primaryEmail"]
-        person.first_name = user["name"]["givenName"]
-        person.last_name = user["name"]["familyName"]
-        if "thumbnailPhotoUrl" in user:
-            person.avatar_url = user["thumbnailPhotoUrl"]
+
+        person.properties = PersonProperties()
+        person.properties.first_name = user["name"]["givenName"]
+        person.properties.last_name = user["name"]["familyName"]
+        # ignore the private avatar URL until [ch969] is fixed, login user can still get this from OKTA
+        # if "thumbnailPhotoUrl" in user:
+        #    person.avatar_url = user["thumbnailPhotoUrl"]
 
         self._users.append(person)
 
