@@ -87,16 +87,18 @@ class SnowflakeExtractor(BaseExtractor):
     def _fetch_tables(self, cursor, database: str) -> List[Tuple[str, str, str]]:
         cursor.execute("USE " + database)
         cursor.execute(
-            "SELECT table_schema, table_name, table_type "
+            "SELECT table_schema, table_name, table_type, COMMENT "
             "FROM information_schema.tables "
             "WHERE table_schema != 'INFORMATION_SCHEMA' "
             "ORDER BY table_schema, table_name"
         )
 
         tables: List[Tuple[str, str, str]] = []
-        for schema, name, table_type in cursor:
+        for schema, name, table_type, comment in cursor:
             full_name = self._table_fullname(database, schema, name)
-            self._datasets[full_name] = self._init_dataset(full_name, table_type)
+            self._datasets[full_name] = self._init_dataset(
+                full_name, table_type, comment
+            )
             tables.append((schema, name, full_name))
 
         return tables
@@ -127,7 +129,7 @@ class SnowflakeExtractor(BaseExtractor):
             logger.error(e)
 
     @staticmethod
-    def _init_dataset(full_name: str, table_type: str) -> Dataset:
+    def _init_dataset(full_name: str, table_type: str, comment: str) -> Dataset:
         dataset = Dataset()
         dataset.entity_type = EntityType.DATASET
         dataset.logical_id = DatasetLogicalID()
@@ -137,6 +139,7 @@ class SnowflakeExtractor(BaseExtractor):
         dataset.schema = DatasetSchema()
         dataset.schema.aspect_type = AspectType.DATASET_SCHEMA
         dataset.schema.schema_type = SchemaType.SQL
+        dataset.schema.description = comment
         dataset.schema.fields = []
         dataset.schema.sql_schema = SQLSchema()
         dataset.schema.sql_schema.materialization = (
